<?php

namespace Drupal\simple_message\Controller;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Drupal\simple_message\Entity\Message;
use Drupal\simple_message\MessageApi;
use Drupal\user\Entity\User;
use Laminas\Diactoros\Response\JsonResponse;
use Symfony\Component\DependencyInjection\ContainerInterface;


/**
 * Class MessageController.
 */
class MessageController extends ControllerBase
{

  /**
   * @var MessageApi
   */
  protected $simpleMessageApi;
  /**
   * Drupal\Core\Session\AccountProxyInterface definition.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * Drupal\webprofiler\Entity\EntityManagerWrapper definition.
   *
   * @var \Drupal\webprofiler\Entity\EntityManagerWrapper
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container)
  {
    $instance = parent::create($container);
    $instance->currentUser = $container->get('current_user');
    $instance->entityTypeManager = $container->get('entity_type.manager');
    $instance->simpleMessageApi = $container->get('simple_message.message_api');

    return $instance;
  }

  /**
   * Remove message action
   */
  function removeMessage(Message $message)
  {
    if ($message->get('status')->value == Message::TYPE_READ) {
      $message->set('status', Message::TYPE_REMOVED_ONCE);
    } else {
      $message->set('status', Message::TYPE_REMOVED_TWICE);
    }
    $status = $message->save();
    return new JsonResponse(['status' => $status]);
  }

  /**
   * display inbox messages
   */
  function messages($sender = null)
  {
    $sender = User::load($sender);

    $senders = views_embed_view('message_inbox_senders', 'block_1');
    $messages = $this->t('Please select a discussion thread');
    $form = '';

    if (isset($sender)) {
      $args = serialize([$this->currentUser()->id(), $sender->id()]);
      $messages = views_embed_view('messages_inbox', 'block_1', $args);
      if ($messages) {
        $this->simpleMessageApi->setMessagesAsReadBySender($sender);
      }
      $form = \Drupal::entityTypeManager()
        ->getFormObject('simple_message', 'send_message')
        ->setEntity(Message::create([
          'sender_user' => $this->currentUser()->id(),
          'receiver_user' => $sender,
        ]));
      $form = $this->formBuilder()->getForm($form);
    }
    $newDiscussionLink = [
      '#type' => 'link',
      '#title' => $this->t('<i class="fa fa-plus"></i> New discussion'),
      '#url' => Url::fromRoute('simple_message.new_discussion'),
      '#access' => $this->currentUser()->hasPermission('start new discussion'),
      '#options' => [
        'attributes' => [
          'class' => ['btn btn-success'],
        ],
      ],
    ];

    if ($this->config('ddd')->get('use_ajax_on_new_mgs')) {
      $newDiscussionLink['#options']['attributes']['class'][] = 'use-ajax';
      $newDiscussionLink['#options']['attributes']['data-dialog-type'] = 'modal';
      $newDiscussionLink['#options']['attributes']['data-dialog-options'] = Json::encode(['width' => 700]);
    }

    return [
      "#theme" => 'inbox_messages',
      "#senders" => $senders,
      '#sender' => $sender,
      "#messages" => $messages,
      "#form" => $form,
      '#settings' => $this->config('simple_message.settings'),
      "#new_discussion_link" => $newDiscussionLink,
      "#attached" => [
        'library' => ['simple_message/simple_message']
      ]
    ];
  }

}
