<?php

namespace Drupal\simple_message\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class MessageSettingsForm.
 *
 * @ingroup simple_message
 */
class MessageSettingsForm extends ConfigFormBase {

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'simple_message_settings';
  }

  protected function getEditableConfigNames()
  {
    return [
      'simple_message.settings',
    ];
  }

  /**
   * Defines the settings form for Message entities.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   Form definition array.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $form['display_layout'] = [
      '#title' => $this->t('Layout'),
      '#type' => 'select',
      '#description' => $this->t('Layout of message thread'),
      '#options' => ['one_column' => 'One column', 'two_columns' => 'Two columns'],
      '#default_value' =>  $this->config('simple_message.settings')->get('display_layout') ?? 'two_columns'
    ];

    $form['use_ajax_on_new_mgs'] = [
      '#title' => $this->t('Use ajax on the button'),
      '#type' => 'checkbox',
      '#description' => $this->t('Load form to start a new discussion on ajax popup'),
      '#default_value' =>  $this->config('simple_message.settings')->get('use_ajax_on_new_mgs') ?? false
    ];
    return $form;
  }

  /**
   * Form submission handler.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $this->config('simple_message.settings')
      ->set('display_layout', $form_state->getValue('display_layout'))
      ->set('use_ajax_on_new_mgs', $form_state->getValue('use_ajax_on_new_mgs'))
      ->save();
  }

}
