<?php

namespace Drupal\simple_message;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Render\RendererInterface;
use Drupal\simple_message\Entity\Message;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\simple_message\Entity\MessageInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Class MessageApi.
 */
class MessageApi {

  /**
   *
   * @var EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new MessageApi object.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * get user message count by status
   */
  function getUserMessageCountPerStatus($user, $status, $sender = null)
  {
    $query = $this->entityTypeManager
      ->getStorage('simple_message')
      ->getQuery();
    $query->condition('receiver_user', $user->id(), '=')
      ->condition('status', $status, '=');
    if ($sender) {
      $id = is_object($sender) ? $sender->id() : $sender;
      $query->condition('sender_user', $id, '=');
    }
    return $query->count()->execute();
  }

  /**
   * Update message status by sender
   */
  function setMessagesAsReadBySender($sender)
  {
    $id = is_object($sender) ? $sender->id() : $sender;
    \Drupal::database()
      ->update('simple_message')
      ->fields([
        'status' => MessageInterface::TYPE_READ
      ])
      ->condition('sender_user', $id, '=')
      ->condition('state', 1)
      ->execute();
    $this->entityTypeManager->getStorage('simple_message')->resetCache();
  }

  /**
   * Get last message by sender
   */
  function getLastMessageBySender($sender){
    $sender_id = is_object($sender) ? $sender->id() : $sender;
    $query = $this->entityTypeManager
      ->getStorage('simple_message')
      ->getQuery()
      ->condition('sender_user', $sender_id)
      ->condition('state', 1)
      ->sort('created', 'DESC')
      ->range(0, 1);
     $ids = $query->execute();

     if (!empty($ids)){
       return Message::load(array_pop($ids));
     }
    return null;
  }

}
